#!/bin/bash
# This is a script to build a Zenwalk package. Check the Zenwalk homepage: www.zenwalk.org
#
# SOFTWARE			: hardinfo
# PROJECT HOMEPAGE 	: http://hardinfo.berlios.de/HomePage
# SOURCE           	: http://download.berlios.de/hardinfo/
#
# AUTHOR         	: skywatcher (s.skywatcher|AT|gmail|DOT|com, simone antoniucci)
# LATEST REVISION	: 2009-04-05
#
# BUILD-ONLY DEPS	: -
# NOTES				: -

### Checking for unbound variables
set -u

### Setting main variables
NAME="hardinfo"
VERSION="0.5.1"
ARCH="i686"
CPU="i686"
BUILD=62.1

HOMEPAGE="http://hardinfo.berlios.de/HomePage"
DESCRIPTION="system profiler and benchmark"
SRCLNK="http://download.berlios.de/hardinfo/$NAME-$VERSION.tar.bz2"

CWD=`pwd`
PKGDIR=$CWD/$NAME-install
PKG=$NAME-$VERSION-$ARCH-$BUILD
SRCPKG=`echo $SRCLNK | rev | cut -d/ -f1 | rev`
SRCDIR=$CWD/$NAME-$VERSION
ICONDIR=$PKGDIR/usr/share/icons/hicolor/48x48/apps/		

URL=http://zenwalk.pinguix.com/user-accounts/skywatcher/$NAME/$VERSION
DOCS="LICENSE TODO"

NJOBS="-j2"
export CFLAGS="-O2 -march=$ARCH -mtune=$CPU"
export CXXFLAGS="-O2 -march=$ARCH -mtune=$CPU"

### Cleaning
rm -rf $PKGDIR
rm -rf $SRCDIR

### Mkdir
mkdir -p $PKGDIR
mkdir -p $PKGDIR/install
mkdir -p $PKGDIR/usr/doc/$NAME-$VERSION
mkdir -p $PKGDIR/usr/src/$NAME-$VERSION
mkdir -p $PKGDIR/usr/share/applications
mkdir -p $ICONDIR

### Checking if source is present. If it's not, download it
if [ -f $SRCPKG ]; then
	echo "Source file is already present, no need to download it";
else
 	echo "Downloading source..."
	wget -c -nv $SRCLNK
fi

### Extracting source
tar xfv $SRCPKG

### Configure, make, install
cd $SRCDIR
sed -i "s:-Wall:-Wall -march=i686 -mtune=i686:" Makefile.in
./configure --prefix=/usr || exit 1
make $NJOBS || exit 1
make install DESTDIR=$PKGDIR || exit 1

### Stripping binaries
cd $PKGDIR
find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

### Docs, man, info
cd $SRCDIR
cp -a $DOCS $PKGDIR/usr/doc/$NAME-$VERSION

### Adding build-file to the package
cp -a $CWD/$0 $PKGDIR/usr/src/$NAME-$VERSION/build-$NAME.sh
chmod a+x $PKGDIR/usr/src/$NAME-$VERSION/build-$NAME.sh

### Slack-desc 
#    |-----handy-ruler------------------------------------------------------|
cat > $PKGDIR/install/slack-desc << EOF
$NAME: $NAME - $DESCRIPTION
$NAME:  
$NAME: HardInfo can gather information about your system's hardware and 
$NAME: operating system, perform benchmarks, and generate printable reports
$NAME: either in HTML or in plain text formats.
$NAME: 
$NAME: 
$NAME: 
$NAME:
$NAME: 
$NAME: $HOMEPAGE
EOF

### Desktop entry
sed -i "s:Icon=/usr/share/hardinfo/pixmaps/logo.png:Icon=hardinfo:"  $PKGDIR/usr/share/applications/$NAME.desktop 

### Icon
cd $ICONDIR 
cp -a  ../../../../$NAME/pixmaps/logo.png $NAME.png || exit 1

### Ownerships and permissions
cd $PKGDIR
chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

### Unneeded stuff
rmdir $PKGDIR/usr/local 

### Making the package
makepkg -l y -c n $CWD/$PKG.tgz

### md5 file
cd $CWD
md5sum $PKG.tgz > $PKG.md5

### dep file
depfinder $PKG.tgz > $PKG.dep

### txt file
cat $PKGDIR/install/slack-desc > $PKG.txt

### src file
rm -fr $PKG.src
for link in $URL/$0 $SRCLNK
	do echo $link >> $PKG.src
done

### Cleaning
rm -rf $SRCDIR
rm -rf $PKGDIR

### Done. Ciao!
